@@ -34,9 +34,19 @@ DBusHandlerResult DBusMsgHandler(DBusConnection *connection, DBusMessage *msg, v
   return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
-void callback(DBusPendingCall* /*call*/, void* /*data*/)
+void callback(DBusPendingCall* call, void* /*data*/)
 {
-  // no code
+  DBusMessage *reply;
+
+  reply=dbus_pending_call_steal_reply(call);
+
+  std::cout << "Call finished with reply of type " << dbus_message_type_to_string(dbus_message_get_type(reply)) << std::endl;
+
+  if (dbus_message_get_type(reply)==DBUS_MESSAGE_TYPE_ERROR) {
+    std::cout << "Error: " << dbus_message_get_error_name(reply) << std::endl;
+  }
+
+  dbus_message_unref(reply);
 }
 
 StatusHildon::StatusHildon()
@@ -283,6 +293,8 @@ bool StatusHildon::UpdateNetworks()
 
   std::cout << "Requesting network scan done." << std::endl;
 
+  dbus_message_unref(msg);
+
   return true;
 }
 
@@ -293,10 +305,11 @@ bool StatusHildon::CanChangePowerSaving() const
 
 bool StatusHildon::SetPowerSaving(bool savePower)
 {
-  std::cout << "Requesting power saving switch..." << std::endl;
+  std::cout << "Requesting power saving switch... " << savePower << std::endl;
 
-  DBusMessage *msg;
-  bool        result;
+  DBusMessage     *msg;
+  DBusPendingCall *call;
+  bool            result;
 
   msg=dbus_message_new_method_call("com.nokia.wlancond",
                                    "/com/nokia/wlancond/request",
@@ -307,7 +320,9 @@ bool StatusHildon::SetPowerSaving(bool savePower)
                            DBUS_TYPE_BOOLEAN,&savePower,
                            DBUS_TYPE_INVALID);
 
-  result=dbus_connection_send_with_reply(GetDBusConnection(),msg,NULL,-1);
+  result=dbus_connection_send_with_reply(GetDBusConnection(),msg,&call,-1);
+
+  dbus_pending_call_set_notify(call,callback,NULL,NULL);
 
   dbus_message_unref(msg);
 
