@@ -397,7 +397,7 @@ public:
 
     label=Lum::Label::Create(true,true);
     label->AddLabel(L"ESSID:",CreateTextValue(essid,32));
-    label->AddLabel(L"Chanel:",CreateTextValue(channel,2));
+    label->AddLabel(L"Channel:",CreateTextValue(channel,2));
     label->AddLabel(L"Type:",CreateTextValue(type,32));
     label->AddLabel(L"AP:",CreateTextValue(accesspoint,17));
     label->AddLabel(L"Client:",CreateTextValue(client,28));
